@@ -181,14 +181,17 @@ class ShippingMethod(object):
     EXPRESS = 'express'
     # 自提
     SELF_SERVICE = 'self_service'
-    # 闪送
-    FLASH_DELIVERY = 'flash_delivery'
+    # 无需配送
+    NO_NEED_DELIVERY = 'no_need_delivery'
     # 自费闪送
     SELF_FLASH = 'self_flash'
+    # 闪送
+    FLASH_DELIVERY = 'flash_delivery'
 
     CHOICES = (
-        (EXPRESS, "快递发货"),
-        (SELF_SERVICE, "到店自提"),
+        (EXPRESS, "快递"),
+        (SELF_SERVICE, "自提"),
+        (NO_NEED_DELIVERY, "无需配送"),
         (FLASH_DELIVERY, "闪送"),
         (SELF_FLASH, "自费闪送"),
     )
@@ -197,16 +200,19 @@ class ShippingMethod(object):
     # SELF_SERVICE_INT = 1<<0
     # # 快递
     # EXPRESS_INT = 1<<1
+    # 无需配送
+    # NO_NEED_DELIVERY = 1<<2
     # # 自费闪送
-    # SELF_FLASH_INT = 1<<2
+    # SELF_FLASH_INT = 1<<3
     # # 闪送
-    # FLASH_DELIVERY_INT = 1<<3
+    # FLASH_DELIVERY_INT = 1<<4
 
     str2int_map = {
         SELF_SERVICE: 1 << 0,
         EXPRESS: 1 << 1,
-        SELF_FLASH: 1 << 2,
-        FLASH_DELIVERY: 1 << 3,
+        NO_NEED_DELIVERY: 1 << 2,
+        SELF_FLASH: 1 << 3,
+        FLASH_DELIVERY: 1 << 4,
     }
 
     int2str_map = {v: k for k, v in str2int_map.items()}
@@ -223,3 +229,7 @@ class ShippingMethod(object):
     def total_int_2_strs(cls, total_int):
         ''' 将某个包含多种配送方式的 int 值转为多个 shipping_method '''
         return [v for k, v in cls.int2str_map.items() if k & total_int]
+
+
+# 汉光仓ID
+HG_STORAGE_ID = "0"
