@@ -589,6 +589,8 @@ class DistributeEventConst(object):
     AFSPLUS_COMPLETE = "afsplus_complete"
     AFSPLUS_S2E = "afsplus_s2e"  # 自提转快递
     AFSPLUS_E2S = "afsplus_e2s"  # 快递转自提
+    AFSPLUS_TO_EXPRESS = "afsplus_2e"  # 转快递
+    AFSPLUS_TO_SELF_SERVICE = "afsplus_2s"
 
     # 2022.08 虚拟商品确收
     CUS_CONFIRM_AT_VIRTUAL = "cus_confirm_at_virtual"
@@ -1011,6 +1013,28 @@ class DistributeEventConst(object):
             ],
             DistributeEventConstKey.TO_STATUS_KEY: None
         },
+        AFSPLUS_TO_EXPRESS: {
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.INIT, DistributeStatus.PRINTED,
+                                DistributeStatus.CUSSERVICE_PICKED_UP,
+                                DistributeStatus.GUIDE_PICKED_UP,
+                                DistributeStatus.SERVICE_DESK,
+                                DistributeStatus.SERVICE_STORE,
+                                DistributeStatus.SERVICE_STOP,
+            ],
+            DistributeEventConstKey.TO_STATUS_KEY: None
+        },
+        AFSPLUS_TO_SELF_SERVICE: {
+            DistributeEventConstKey.FROM_STATUS_LIST_KEY: [
+                DistributeStatus.INIT, DistributeStatus.PRINTED,
+                                DistributeStatus.CUSSERVICE_PICKED_UP,
+                                DistributeStatus.GUIDE_PICKED_UP,
+                                DistributeStatus.SERVICE_DESK,
+                                DistributeStatus.SERVICE_STORE,
+                                DistributeStatus.SERVICE_STOP,
+            ],
+            DistributeEventConstKey.TO_STATUS_KEY: None
+        },
 
         # 2022.08 虚拟商品确收事件
         CUS_CONFIRM_AT_VIRTUAL: {
@@ -1100,6 +1124,8 @@ class DistributeEventConst(object):
         AFSPLUS_COMPLETE: "完成特殊售后",
         AFSPLUS_S2E: "自提转快递",  # 自提转快递
         AFSPLUS_E2S: "快递转自提",  # 快递转自提
+        AFSPLUS_TO_EXPRESS: "转快递",
+        AFSPLUS_TO_SELF_SERVICE: "转自提",
 
         # 虚拟商品
         CUS_CONFIRM_AT_VIRTUAL: "虚拟商品确收"
