@@ -1,5 +1,8 @@
 # 这些常量会在其他地方被用到，用作某些判断
+import logging
+import warnings
 
+logger = logging.getLogger(__name__)
 
 class ReversedStockStatus(object):
     # 默认状态
@@ -156,11 +159,20 @@ class OrderTypes(object):
     )
 
 
-class OrderShippingMethods(object):
+class __OrderShippingMethods(object):
+    warnings.warn("已废弃", DeprecationWarning)
 
     SELF_SERVICE = "self_service"
     EXPRESS = "express"
 
+    def __getattribute__(self, name: str):
+        value = super().__getattribute__(name)
+        logger.warn("sparrow_order_lib.sparrow_order.constants.OrderShippingMethod 已废弃, 请使用 sparrow_order_lib.core.constants.ShippingMethod 替换")
+        return value
+
+
+OrderShippingMethods = __OrderShippingMethods()
+
 
 class OrderStatus(object):
     """订单对外展示状态"""
